<?php
/**
 * Paradox Business theme functions and definitions.
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 * @package pxt-business
 */

function pxt_business_ContentWidth() {
    $GLOBALS['content_width'] = apply_filters('pxt_business_ContentWidth', 678);
}

add_action('after_setup_theme', 'pxt_business_ContentWidth', 0);

if (!function_exists('pxt_business_Setup')) {

    /**
     * Sets up theme defaults and registers support for various WordPress features.
     * Note that this function is hooked into the after_setup_theme hook, which
     * runs before the init hook. The init hook is too late for some features, such
     * as indicating support for post thumbnails.
     */
    function pxt_business_Setup() {
        define('PXT_BUSINESS_THEME_VERSION', '1.8');
        /**
         * Make theme available for translation.
         * Translations can be filed in the /languages/ directory.
         */
        load_theme_textdomain('pxt-business', get_template_directory() . '/languages');
        // Add default posts and comments RSS feed links to head.
        add_theme_support('automatic-feed-links');
        /**
         * Let WordPress manage the document title.
         * By adding theme support, we declare that this theme does not use a
         * hard-coded <title> tag in the document head, and expect WordPress to
         * provide it for us.
         */
        add_theme_support('title-tag');
        /**
         * Enable support for Post Thumbnails on posts and pages.
         * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
         */
        add_theme_support('post-thumbnails');
        set_post_thumbnail_size(150, 150, true);
        add_image_size('pxt-business-related', 200, 125, true); //related
        // This theme uses wp_nav_menu() in one location.
        register_nav_menus(array(
            'primary' => esc_html__('Primary', 'pxt-business'),
        ));
        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support('html5', array(
            'comment-form',
            'comment-list',
            'gallery',
            'caption',
        ));
        if (pxt_business_isWcActive()) {
            add_theme_support('woocommerce');
        }
        // Set up the WordPress core custom background feature.
        add_theme_support('custom-background', apply_filters('pxt_business_CustomBackgroundArgs', array(
            'default-color' => esc_attr('#eee'),
            'default-image' => '',
        )));
        /**
         * This theme styles the visual editor to resemble the theme style,
         * specifically font, colors, icons, and column width.
         */
        add_editor_style('css/editor-style.css');
    }

}
add_action('after_setup_theme', 'pxt_business_Setup');

/**
 * Register widget area.
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function pxt_business_WidgetsInit() {
    register_sidebar(array(
        'name' => __('Sidebar', 'pxt-business'),
        'id' => 'sidebar',
        'description' => '',
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>',
    ));
    // First Footer 
    register_sidebar(array(
        'name' => __('Footer 1', 'pxt-business'),
        'description' => __('First footer column', 'pxt-business'),
        'id' => 'footer-first',
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>',
    ));

    // Second Footer 
    register_sidebar(array(
        'name' => __('Footer 2', 'pxt-business'),
        'description' => __('Second footer column', 'pxt-business'),
        'id' => 'footer-second',
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>',
    ));
    // Third Footer 
    register_sidebar(array(
        'name' => __('Footer 3', 'pxt-business'),
        'description' => __('Third footer column', 'pxt-business'),
        'id' => 'footer-third',
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>',
    ));

    if (pxt_business_isWcActive()) {
        // Register WooCommerce Shop and Single Product Sidebar
        register_sidebar(array(
            'name' => __('Shop Page Sidebar', 'pxt-business'),
            'description' => __('Appears on Shop main page and product archive pages.', 'pxt-business'),
            'id' => 'shop-sidebar',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>',
        ));
        register_sidebar(array(
            'name' => __('Single Product Sidebar', 'pxt-business'),
            'description' => __('Appears on single product pages.', 'pxt-business'),
            'id' => 'product-sidebar',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>',
        ));
    }
}

add_action('widgets_init', 'pxt_business_WidgetsInit');

function pxt_business_CustomSidebar() {
    // Default sidebar.
    $pxt_business_sidebar = 'sidebar';
    // Woocommerce.
    if (pxt_business_isWcActive()) {
        if (is_shop() || is_product_category()) {
            $pxt_business_sidebar = 'shop-sidebar';
        }
        if (is_product()) {
            $pxt_business_sidebar = 'product-sidebar';
        }
    }
    return $pxt_business_sidebar;
}

// Enqueue scripts and styles.
function pxt_business_Scripts() {
    wp_enqueue_style('pxt_business_style', get_stylesheet_uri());
    $pxt_business_handle = 'style';
    // WooCommerce
    if (pxt_business_isWcActive()) {
        if (is_woocommerce() || is_cart() || is_checkout()) {
            wp_enqueue_style('pxt_business_woocommerce', get_template_directory_uri() . '/css/woocommerce2.css');
            $pxt_business_handle = 'woocommerce';
        }
    }
    wp_enqueue_style('bootstrap', get_template_directory_uri() . '/css/bootstrap.min.css');    
    wp_enqueue_style('font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css');

    wp_enqueue_script('bootstrap-js', get_template_directory_uri() . '/js/bootstrap.js', array('jquery'), '', true);
    wp_enqueue_script('customscripts', get_template_directory_uri() . '/js/customscripts.js', array('jquery'), '', true);
    
    if (is_singular() && comments_open() && get_option('thread_comments')) {
        wp_enqueue_script('comment-reply');
    }

    $pxt_business_ColorScheme2 = get_theme_mod('pxtBusinessColorScheme2', '#1b1b1b');
    $pxt_business_Layout = get_theme_mod('pxtBusinessLayout', 'cslayout');
    $pxt_business_ColorScheme = get_theme_mod('pxtBusinessColorScheme', '#648ca2');
    $top_header_background_color = get_theme_mod('top_header_background_color', '#fff');
    $pxt_business_header_image = get_header_image();

    $pxt_business_custom_css = '#site-header, header.header { background-image: url(\''.esc_url_raw($pxt_business_header_image).'\'); }
    #tabber .inside li .meta b,footer .widget li a:hover,.fn a,.reply a, a:hover, .sidebar.c-4-12 .textwidget a,#tabber .inside li div.info .entry-title a:hover, .top a:hover, footer .tagcloud a:hover, #navigation ul ul a:hover,.single_post a, #site-footer .textwidget a, #commentform a, #tabber .inside li a, .copyrights a:hover, a, .sidebar.c-4-12 a:hover { color: '.esc_attr($pxt_business_ColorScheme).'; }
    .woocommerce nav.woocommerce-pagination ul li span.current, .woocommerce #content nav.woocommerce-pagination ul li span.current, .woocommerce-page nav.woocommerce-pagination ul li span.current, .woocommerce-page #content nav.woocommerce-pagination ul li span.current, .woocommerce-page nav.woocommerce-pagination ul li a:hover, .woocommerce #content nav.woocommerce-pagination ul li a:hover, .woocommerce nav.woocommerce-pagination ul li a:hover, .woocommerce-page #content nav.woocommerce-pagination ul li a:hover, .woocommerce nav.woocommerce-pagination ul li a:focus, .woocommerce-page nav.woocommerce-pagination ul li a:focus, .woocommerce #content nav.woocommerce-pagination ul li a:focus, .woocommerce-page #content nav.woocommerce-pagination ul li a:focus, .pagination .current, .tagcloud a { border-color: '.esc_attr($pxt_business_ColorScheme).'; }
    span.sticky-post, .nav-previous a:hover, .nav-next a:hover, #commentform input#submit, #searchform input[type="submit"], .home_menu_item, .pagination a:hover, .readMore a, .pxtt-subscribe input[type="submit"], .pagination .current, .primary-navigation, .currenttext, .woocommerce nav.woocommerce-pagination ul li a:focus, .woocommerce nav.woocommerce-pagination ul li a:hover, .woocommerce nav.woocommerce-pagination ul li span.current, .woocommerce-page a.button, .woocommerce button.button, .woocommerce-product-search input[type=\"submit\"], .woocommerce a.button, .woocommerce-page button.button, .woocommerce input.button, .woocommerce-page input.button, .woocommerce #respond input#submit, .woocommerce-page #respond input#submit, .woocommerce #content input.button, .woocommerce-page #content input.button { background-color: '.esc_attr($pxt_business_ColorScheme).'; }
    .corner { border-color: transparent transparent '.esc_attr($pxt_business_ColorScheme).' transparent;}
    .primary-navigation, footer, .readMore a:hover, #commentform input#submit:hover, .featured-thumbnail .latestPost-review-wrapper { background-color: '.esc_attr($pxt_business_ColorScheme2).'; }
    .header{ background-color: '.esc_attr($top_header_background_color).';}';
  $pxt_business_custom_css .= '#site-header { background-color:'.esc_attr($top_header_background_color).' }';
  
    if (!empty($pxt_business_Layout) && $pxt_business_Layout == "sclayout") {
        $pxt_business_custom_css .= ".article { float: right; } .sidebar.c-4-12 { float: left; }";
    }
    wp_add_inline_style($pxt_business_handle, esc_attr($pxt_business_custom_css));
}

add_action('wp_enqueue_scripts', 'pxt_business_Scripts');
require get_template_directory() . '/inc/custom-header.php';
require get_template_directory() . '/inc/template-tags.php';
require get_template_directory() . '/inc/extras.php';
require get_template_directory() . '/inc/pxt-customizer.php';
require get_template_directory() . '/inc/jetpack.php';
include_once( get_template_directory()."/widget/socialMediaIcons.php" );

// Custom Comments template
if (!function_exists('pxt_business_Comments')) {

    function pxt_business_Comment($pxt_business_comment, $pxt_business_args, $pxt_business_depth) {
        ?>
        <li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">
            <div id="comment-<?php comment_ID(); ?>" class="posRelative" itemscope itemtype="http://schema.org/UserComments">
                <div class="comment-author vcard">
                    <?php echo get_avatar($pxt_business_comment->comment_author_email, 70); ?>
                    <div class="comment-metadata">
                        <?php printf('<span class="fn" itemprop="creator" itemscope itemtype="http://schema.org/Person">%s</span>', get_comment_author_link()) ?>
                        <span class="comment-meta">
                            <?php edit_comment_link(__('(Edit)', 'pxt-business'), '  ', '') ?>
                        </span>
                    </div>
                </div>
                <?php if ($pxt_business_comment->comment_approved == '0') { ?>
                    <em><?php __('Your comment is awaiting moderation.', 'pxt-business') ?></em>
                    <br />
                <?php } ?>
                <div class="commentmetadata" itemprop="commentText">
                    <?php comment_text() ?>
                    <time><?php comment_date(get_option('date_format')); ?></time>
                    <span class="reply">
                        <?php comment_reply_link(array_merge($pxt_business_args, array('depth' => $pxt_business_depth, 'max_depth' => $pxt_business_args['max_depth']))) ?>
                    </span>
                </div>
            </div>
        </li>
        <?php
    }

}

// get an excerpt for an article/page
function pxt_business_Excerpt($pxt_business_limit) {
    $pxt_business_excerpt = explode(' ', get_the_excerpt(), $pxt_business_limit);
    if (count($pxt_business_excerpt) >= $pxt_business_limit) {
        array_pop($pxt_business_excerpt);
        $pxt_business_excerpt = implode(" ", $pxt_business_excerpt);
    } else {
        $pxt_business_excerpt = implode(" ", $pxt_business_excerpt);
    }
    $pxt_business_excerpt = preg_replace('`[[^]]*]`', '', $pxt_business_excerpt);
    return $pxt_business_excerpt;
}

/**
 * Shorthand function to check for more tag in post.
 * @return bool|int
 */
function pxt_business_PostHasMoretag() {
    return strpos(get_the_content(), '<!--more-->');
}

if (!function_exists('pxt_business_Readmore')) {

    // Display a "read more" link.
    function pxt_business_Readmore() {
        ?>
        <div class="readMore">
            <a href="<?php echo esc_url(get_the_permalink()); ?>" title="<?php the_title_attribute(); ?>">
                <?php esc_html_e('Read More', 'pxt-business'); ?>
            </a>
        </div>
        <?php
    }

}

// Manageing the Breadcrumbs
if (!function_exists('pxt_business_Breadcrumb')) {

    function pxt_business_Breadcrumb() {
        if (is_front_page()) {
            return;
        }
        echo '<span typeof="v:Breadcrumb" class="root"><a rel="v:url" property="v:title" href="';
        echo esc_url(home_url());
        echo '">' . esc_html(sprintf(__("Home", 'pxt-business')));
        echo '</a></span><span><i class="paradox-icon icon-angle-double-right"></i></span>';
        if (is_single()) {
            $pxt_business_categories = get_the_category();
            if ($pxt_business_categories) {
                $pxt_business_level = 0;
                $pxt_business_hierarchy_arr = array();
                foreach ($pxt_business_categories as $pxt_business_cat) {
                    $pxt_business_anc = get_ancestors($pxt_business_cat->term_id, 'category');
                    $pxt_business_count_anc = count($pxt_business_anc);
                    if (0 < $pxt_business_count_anc && $pxt_business_level < $pxt_business_count_anc) {
                        $pxt_business_level = $pxt_business_count_anc;
                        $pxt_business_hierarchy_arr = array_reverse($pxt_business_anc);
                        array_push($pxt_business_hierarchy_arr, $pxt_business_cat->term_id);
                    }
                }
                if (empty($pxt_business_hierarchy_arr)) {
                    $pxt_business_category = $pxt_business_categories[0];
                    echo '<span typeof="v:Breadcrumb"><a href="' . esc_url(get_category_link($pxt_business_category->term_id)) . '" rel="v:url" property="v:title">' . esc_html($pxt_business_category->name) . '</a></span><span><i class="paradox-icon icon-angle-double-right"></i></span>';
                } else {
                    foreach ($pxt_business_hierarchy_arr as $pxt_business_cat_id) {
                        $pxt_business_category = get_term_by('id', $pxt_business_cat_id, 'category');
                        echo '<span typeof="v:Breadcrumb"><a href="' . esc_url(get_category_link($pxt_business_category->term_id)) . '" rel="v:url" property="v:title">' . esc_html($pxt_business_category->name) . '</a></span><span><i class="paradox-icon icon-angle-double-right"></i></span>';
                    }
                }
            }
            echo "<span><span>";
            the_title();
            echo "</span></span>";
        } elseif (is_page()) {
            $pxt_business_parent_id = wp_get_post_parent_id(get_the_ID());
            if ($pxt_business_parent_id) {
                $pxt_business_breadcrumbs = array();
                while ($pxt_business_parent_id) {
                    $pxt_business_page = get_page($pxt_business_parent_id);
                    $pxt_business_breadcrumbs[] = '<span typeof="v:Breadcrumb"><a href="' . esc_url(get_permalink($pxt_business_page->ID)) . '" rel="v:url" property="v:title">' . esc_html(get_the_title($pxt_business_page->ID)) . '</a></span><span><i class="paradox-icon icon-angle-double-right"></i></span>';
                    $pxt_business_parent_id = $pxt_business_page->post_parent;
                }
                $pxt_business_breadcrumbs = array_reverse($pxt_business_breadcrumbs);
                foreach ($pxt_business_breadcrumbs as $pxt_business_crumb) {
                    echo esc_html($pxt_business_crumb);
                }
            }
            echo "<span><span>";
            the_title();
            echo "</span></span>";
        } elseif (is_category()) {
            global $wp_query;
            $pxt_business_cat_obj = $wp_query->get_queried_object();
            $this_cat_id = $pxt_business_cat_obj->term_id;
            $pxt_business_hierarchy_arr = get_ancestors($this_cat_id, 'category');
            if ($pxt_business_hierarchy_arr) {
                $pxt_business_hierarchy_arr = array_reverse($pxt_business_hierarchy_arr);
                foreach ($pxt_business_hierarchy_arr as $pxt_business_cat_id) {
                    $pxt_business_category = get_term_by('id', $pxt_business_cat_id, 'category');
                    echo '<span typeof="v:Breadcrumb"><a href="' . esc_url(get_category_link($pxt_business_category->term_id)) . '" rel="v:url" property="v:title">' . esc_html($pxt_business_category->name) . '</a></span><span><i class="paradox-icon icon-angle-double-right"></i></span>';
                }
            }
            echo "<span><span>";
            single_cat_title();
            echo "</span></span>";
        } elseif (is_author()) {
            echo "<span><span>";
            if (get_query_var('author_name')) :
                $pxt_business_curauth = get_user_by('slug', get_query_var('author_name'));
            else :
                $pxt_business_curauth = get_userdata(get_query_var('author'));
            endif;
            echo esc_html($pxt_business_curauth->nickname);
            echo "</span></span>";
        } elseif (is_search()) {
            echo "<span><span>";
            the_search_query();
            echo "</span></span>";
        } elseif (is_tag()) {
            echo "<span><span>";
            single_tag_title();
            echo "</span></span>";
        }
    }

}

/**
 * WP Mega Menu Plugin Support
 */
function pxt_business_MegamenuParentElement($selector) {
    return '.primary-navigation .container';
}

add_filter('wpmm_container_selector', 'pxt_business_MegamenuParentElement');

/**
 * Determines whether the WooCommerce plugin is active or not.
 * @return bool
 */
function pxt_business_isWcActive() {
    if (is_multisite()) {
        
        return is_plugin_active('woocommerce/woocommerce.php');
    } else {
        return in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')));
    }
}

// WooCommerce
if (pxt_business_isWcActive()) {
    if (!function_exists('pxt_business_LoopColumns')) {

        /**
         * Change number or products per row to 3
         * @return int
         */
        function pxt_business_LoopColumns() {
            return 3; // 3 products per row
        }

    }
    add_filter('loop_shop_columns', 'pxt_business_LoopColumns');

    /**
     * Redefine woocommerce_output_related_products()
     */
    function woocommerce_output_related_products() {
        $pxt_business_args = array('posts_per_page' => 3, 'columns' => 3);
        woocommerce_related_products($pxt_business_args); // Display 3 products in rows of 1
    }
    

    /**
     * Change the number of product thumbnails to show per row to 4.
     * @return int
     */
    function pxt_business_WoocommerceThumbCols() {
        return 4; // .last class applied to every 4th thumbnail
    }

    add_filter('woocommerce_product_thumbnails_columns', 'pxt_business_WoocommerceThumbCols');

    /**
     * Ensure cart contents update when products are added to the cart via AJAX.
     * @param $pxt_business_fragments
     * @return mixed
     */
    function pxt_business_HeaderAddToCartFragment($pxt_business_fragments) {
        global $woocommerce;
        ob_start();
        ?>  
        <a class="cart-contents" href="<?php echo esc_url($woocommerce->cart->get_cart_url()); ?>" title="<?php esc_attr__('View your shopping cart', 'pxt-business'); ?>">
            <?php echo esc_html(sprintf(_n('%d item', '%d items', esc_html($woocommerce->cart->cart_contents_count), 'pxt-business'), esc_html($woocommerce->cart->cart_contents_count))); ?> - <?php echo esc_html($woocommerce->cart->get_cart_total()); ?>
        </a>
        <?php
        $pxt_business_fragments['a.cart-contents'] = ob_get_clean();
        return $pxt_business_fragments;
    }

    add_filter('add_to_cart_fragments', 'pxt_business_HeaderAddToCartFragment');

    /**
     * Optimize WooCommerce Scripts
     * Updated for WooCommerce 2.0+
     * Remove WooCommerce Generator tag, styles, and scripts from non WooCommerce pages.
     */
    function pxt_business_ManageWoocommerceStyles() {
        //remove generator meta tag
        remove_action('wp_head', array($GLOBALS['woocommerce'], 'generator'));
        //first check that woo exists to prevent fatal errors
        if (function_exists('is_woocommerce')) {
            //dequeue scripts and styles
            if (!is_woocommerce() && !is_cart() && !is_checkout()) {
                wp_dequeue_style('woocommerce-layout');
                wp_dequeue_style('woocommerce-smallscreen');
                wp_dequeue_style('woocommerce-general');
                wp_dequeue_style('wc-bto-styles'); //Composites Styles
                wp_dequeue_script('wc-add-to-cart');
                wp_dequeue_script('wc-cart-fragments');
                wp_dequeue_script('woocommerce');
                wp_dequeue_script('jquery-blockui');
                wp_dequeue_script('jquery-placeholder');
            }
        }
    }

    add_action('wp_enqueue_scripts', 'pxt_business_ManageWoocommerceStyles', 99);
    // Remove WooCommerce generator tag.
    remove_action('wp_head', 'wc_generator_tag');
}

// Post Layout for Archives
if (!function_exists('pxt_business_ArchivePost')) {

    /**
     * Display a post of specific layout.
     * @param string $layout
     */
    function pxt_business_ArchivePost($layout = '') {
        $pxt_business_lite_full_posts = get_theme_mod('pxt_business_lite_full_posts', '0');
        ?>
        <article class="post excerpt">
            <?php
            if (is_sticky() && is_home() && !is_paged()) {
                printf(wp_kses('<span class="sticky-post">%s</span>', array('span'=>array('class'=>array()))), esc_html(__('Featured', 'pxt-business')));
            }
            ?>   
            <?php if (is_single()) : ?>
                <div class="post-date-paradox"><?php the_time(get_option('date_format')); ?></div>
            <?php endif; ?>
            <header>
                <h2 class="title">
                    <a href="<?php the_permalink() ?>" title="<?php the_title_attribute(); ?>" rel="bookmark"><?php the_title(); ?></a>
                </h2>
            </header><!--.header-->
            <?php if (empty($pxt_business_lite_full_posts)) : ?>
                <?php if (has_post_thumbnail()) { ?>
                    <a href="<?php the_permalink() ?>" title="<?php the_title_attribute(); ?>" id="featured-thumbnail">
                        <div class="featured-thumbnail">
                            <?php the_post_thumbnail('pxt-business-featured', array('title' => '')); ?>
                            <?php if (function_exists('wp_review_show_total')) wp_review_show_total(true, 'latestPost-review-wrapper'); ?>
                        </div>
                    </a>
                <?php } else { ?>
                <?php } ?>
                <div class="post-content">
                    <?php echo esc_html(pxt_business_Excerpt(56)); ?>
                </div>
                <?php pxt_business_Readmore(); ?>
            <?php else : ?>
                <div class="post-content full-post">
                    <?php the_content(); ?>
                </div>
                <?php if (pxt_business_PostHasMoretag()) : ?>
                    <?php pxt_business_Readmore(); ?>
                <?php endif; ?>
            <?php endif; ?>
        </article>
        <?php
    }

}

function pxt_business_LoadCustomAdminStyle($hook) {
    if ('appearance_page_about-pxtBusiness' !== $hook) {
        return;
    }
    wp_enqueue_style('pxt-business-custom-admin-css', get_template_directory_uri() . '/css/themeinfo.css', false, '1.0.0');
}

add_action('customize_controls_print_styles', 'pxt_business_CustomizerStylesheet');
add_action('admin_enqueue_scripts', 'pxt_business_LoadCustomAdminStyle');
