<?php
/**
 * Custom functions that act independently of the theme templates.
 * Eventually, some of the functionality here could be replaced by core features.
 * @package pxt-business
 */

function pxt_business_RegisterBackend() {
	add_theme_page( esc_html__('Paradox Themes', 'pxt-business'), esc_html__('Paradox Themes', 'pxt-business'), 'edit_theme_options', 'about-pxt-business', 'pxt_business_Backend');
}

/**
 * Adds custom classes to the array of body classes.
 * @param array $pxt_business_classes Classes for the body element.
 * @return array
 */
function pxt_business_BodyClasses( $pxt_business_classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$pxt_business_classes[] = 'group-blog';
	}
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$pxt_business_classes[] = 'hfeed';
	}
	return $pxt_business_classes;
}

function pxt_business_Backend(){ 
	$pxt_business_url = get_template_directory_uri();
	$pxt_business_premiumImg = "{$pxt_business_url}/images/pxt-business.png";
	?>
	<div class="theme-info-wrapper">
		<div class="theme-info-inner">
			<div class="theme-info-left">
				<div class="theme-info-left-inner">
					<h2><?php echo esc_html(__('Theme issues?', 'pxt-business'));?></h2>
					<p>
						<?php echo esc_html(__('If you are having theme related problems then please contact us through our', 'pxt-business'));?> <a href="<?php echo esc_url_raw('http://paradoxthemes.com/contact-us/')?>" target="_blank"><?php echo esc_html(__('contact form', 'pxt-business'));?></a>, <?php echo esc_html(__('which can be found at', 'pxt-business'));?> <a href="http://paradoxthemes.com/contact-us/" target="_blank"><?php echo esc_url_raw('http://paradoxthemes.com/contact-us/')?></a>
					</p>	
					<h2><?php echo esc_html(__('Need more help?', 'pxt-business'));?></h2>
					<ul>
						<li><a href="http://www.paradoxthemes.com/free/pxt-business/" target="_blank"><?php echo esc_html(__('Pxt business Premium', 'pxt-business'));?></a></li>
						<li><a href="http://www.paradoxthemes.com/contact/" target="_blank"><?php echo esc_html(__('Contact Paradox themes', 'pxt-business'));?></a></li>
						<li><a href="https://wordpress.org/support/" target="_blank"><?php echo esc_html(__('WordPress Support Forum', 'pxt-business'));?></a></li>
					</ul>
					<h2><?php  echo esc_html(__('Plugin or WordPress issues?', 'pxt-business'));?></h2>
					<p><?php  echo esc_html(__('If you are experiencing issues with plugins, please contact the plugin author. 
						If you are experiencing issues with WordPress functionality then please visit the', 'pxt-business'));?> <a href="<?php  echo esc_url_raw('https://wordpress.org/support/');?>" target="_blank"><?php echo esc_html(__('WordPress Support Forum', 'pxt-business'));?></a>.
					</p>
				</div>
			</div>
			<div class="theme-info-right">
				<a href="<?php  echo esc_url_raw('http://www.paradoxthemes.com/free/pxt-business');?>" target="_blank">
					<img src="<?php echo esc_html($pxt_business_premiumImg);?>">
				</a>
			</div>
		</div>
	</div>
<?php }
add_filter( 'body_class', 'pxt_business_BodyClasses' );
add_action( 'admin_menu', 'pxt_business_RegisterBackend' );
